@@ -394,6 +394,7 @@ public Q_SLOTS:
 
     void toggleAlarm(const Akonadi::Item &incidence);
     void toggleTodoCompleted(const Akonadi::Item &incidence);
+    void toggleOccurrenceCompleted(const Akonadi::Item &, const QDate &);
     void copyIncidenceToResource(const Akonadi::Item &incidence, const Akonadi::Collection &col);
     void moveIncidenceToResource(const Akonadi::Item &incidence, const Akonadi::Collection &col);
     void dissociateOccurrences(const Akonadi::Item &incidence, QDate date);
@@ -619,6 +620,8 @@ public:
     */
     QDate activeDate(bool fallbackToToday = false);
 
+    static void toggleCompleted(KCalendarCore::Todo::Ptr, const QDate &);
+
 protected:
     int msgItemDelete(const Akonadi::Item &incidence);
 
@@ -656,7 +659,12 @@ private:
 
     void createPrinter();
 
-    void dissociateOccurrence(const Akonadi::Item &incidence, const QDate &, bool futureOccurrences);
+    /**
+     * Return the recurrence ID of  the occurrence of @p incidence displayed on @displayDate.
+     */
+    static QDateTime recurrenceOnDate(KCalendarCore::Incidence::Ptr incidence, QDate displayDate);
+
+    void dissociateOccurrence(const Akonadi::Item& item, const QDateTime& recurrenceId, bool thisAndFuture);
 
     /**
      * Returns the default collection.
