@@ -9,13 +9,13 @@
 #include "searchcollectionhelper.h"
 #include "korganizer_debug.h"
 
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/CollectionFetchScope>
-#include <AkonadiCore/CollectionModifyJob>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/PersistentSearchAttribute>
-#include <AkonadiCore/SearchCreateJob>
-#include <AkonadiCore/SearchQuery>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/CollectionModifyJob>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/PersistentSearchAttribute>
+#include <Akonadi/SearchCreateJob>
+#include <Akonadi/SearchQuery>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Journal>
@@ -27,11 +27,11 @@ using namespace KOrg;
 
 SearchCollectionHelper::SearchCollectionHelper(QObject *parent)
     : QObject(parent)
+    , mIdentityManager(KIdentityManagement::IdentityManager::self())
 {
-    mIdentityManager = KIdentityManagement::IdentityManager::self();
     setupSearchCollections();
-    connect(mIdentityManager, QOverload<>::of(&KIdentityManagement::IdentityManager::changed), this, &SearchCollectionHelper::updateOpenInvitation);
-    connect(mIdentityManager, QOverload<>::of(&KIdentityManagement::IdentityManager::changed), this, &SearchCollectionHelper::updateDeclinedInvitation);
+    connect(mIdentityManager, qOverload<>(&KIdentityManagement::IdentityManager::changed), this, &SearchCollectionHelper::updateOpenInvitation);
+    connect(mIdentityManager, qOverload<>(&KIdentityManagement::IdentityManager::changed), this, &SearchCollectionHelper::updateDeclinedInvitation);
 }
 
 void SearchCollectionHelper::setupSearchCollections()
